@@ -18,3 +18,6 @@ __all__ = [
     "Callback",
     "Message",
 ]
+
+Message.model_rebuild()
+Callback.model_rebuild()
